*****
Audio
*****

.. module:: spotify

.. autoclass:: AudioBufferStats
    :no-inherited-members:

    .. attribute:: samples

        Number of samples currently in the buffer.

    .. attribute:: stutter

        Number of stutters (audio dropouts) since the last query.

.. autoclass:: AudioFormat

.. autoclass:: Bitrate
    :no-inherited-members:

.. autoclass:: SampleType
    :no-inherited-members:
